@@ -80,6 +80,15 @@ class CarouselItemAPIUnitTest(TestCase):
         res = req.get(url, content_type='application/json',)
         assert isinstance(res.json(), dict)
 
+        # redis lock set
+        ct = ContentType.objects.get_for_model(carousel_item)
+        url = reverse('unicms_api:editorial-board-redis-lock-set')
+        data = {'content_type_id': ct.pk,
+                'object_id': carousel_item.pk}
+        res = req.post(url, data,
+                       content_type='application/json', follow=1)
+        assert isinstance(res.json(), dict)
+
         # GET, patch, put, delete
         url = reverse('unicms_api:carousel-item',
                       kwargs={'carousel_id': carousel.pk,
