@@ -3,12 +3,8 @@ import logging
 from django.test import TestCase
 
 from cms.carousels.tests import CarouselUnitTest
-
 from cms.contexts.tests import ContextUnitTest
 
-from .. concurrency import (is_lock_cache_available,
-                            get_lock_from_cache,
-                            set_lock_to_cache)
 from .. views.generics import check_locks
 
 
@@ -33,8 +29,8 @@ class RedisLockTest(TestCase):
                                             is_superuser=True)
         carousel = CarouselUnitTest.create_carousel()
 
-        check_locks(user=user1, item=carousel, force=True)
+        check_locks(user=user1, item=carousel)
         try:
-            check_locks(user=user2, item=carousel, force=True)
+            check_locks(user=user2, item=carousel)
         except: # pragma: no cover
             logger.info('Exception raised! right!')
