@@ -6,7 +6,7 @@ from . views import (carousel, carousel_item, carousel_item_link,
                      media, media_collection, media_collection_item,
                      publication, publication_attachment,
                      publication_link, publication_localization,
-                     publication_gallery, publication_block,
+                     publication_media_collection, publication_block,
                      publication_related,
                      website, webpath, webpath_pub_context,
                      page, page_block, page_carousel, page_link,
@@ -70,6 +70,8 @@ urlpatterns += path(f'{c_prefix}/', carousel.CarouselList.as_view(), name='carou
 urlpatterns += path(f'{c_prefix}/<int:pk>/', carousel.CarouselView.as_view(), name='carousel'),
 urlpatterns += path(f'{c_prefix}/<int:pk>/logs/', carousel.CarouselLogsView.as_view(), name='carousel-logs'),
 urlpatterns += path(f'{c_prefix}/form/', carousel.CarouselFormView.as_view(), name='carousel-form'),
+urlpatterns += path(f'{c_prefix}/options/', carousel.CarouselOptionList.as_view(), name='carousel-options'),
+urlpatterns += path(f'{c_prefix}/options/<int:pk>/', carousel.CarouselOptionView.as_view(), name='carousel-option'),
 
 # carousel items
 ci_prefix = f'{c_prefix}/<int:carousel_id>/items'
@@ -121,6 +123,8 @@ urlpatterns += path(f'{eb_prefix}/sites/webpaths/', webpath.WebpathAllList.as_vi
 urlpatterns += path(f'{eb_prefix}/sites/webpaths/options/', webpath.WebpathAllOptionList.as_view(), name='webpath-all-options'),
 urlpatterns += path(f'{w_prefix}/options/', webpath.WebpathOptionList.as_view(), name='webpath-options'),
 urlpatterns += path(f'{w_prefix}/options/<int:pk>/', webpath.WebpathOptionView.as_view(), name='webpath-option'),
+urlpatterns += path(f'{w_prefix}/<int:pk>/clone/', webpath.WebpathCloneView.as_view(), name='editorial-board-site-webpath-clone'),
+urlpatterns += path(f'{w_prefix}/<int:pk>/clone/form/', webpath.WebpathCloneFormView.as_view(), name='editorial-board-site-webpath-clone-form'),
 
 # pages
 pa_prefix = f'{w_prefix}/<int:webpath_id>/pages'
@@ -280,14 +284,14 @@ urlpatterns += path(f'{puli_prefix}/<int:pk>/logs/', publication_link.Publicatio
                     name='editorial-board-publication-link-logs'),
 urlpatterns += path(f'{puli_prefix}/form/', publication_link.PublicationLinkFormView.as_view(), name='editorial-board-publication-link-form'),
 
-# publication galleries
-pug_prefix = f'{pu_prefix}/<int:publication_id>/galleries'
-urlpatterns += path(f'{pug_prefix}/', publication_gallery.PublicationGalleryList.as_view(), name='editorial-board-publication-galleries'),
-urlpatterns += path(f'{pug_prefix}/<int:pk>/', publication_gallery.PublicationGalleryView.as_view(), name='editorial-board-publication-gallery'),
-urlpatterns += path(f'{pug_prefix}/<int:pk>/logs/', publication_gallery.PublicationGalleryLogsView.as_view(),
-                    name='editorial-board-publication-gallery-logs'),
-urlpatterns += path(f'{pug_prefix}/form/', publication_gallery.PublicationGalleryFormView.as_view(),
-                    name='editorial-board-publication-gallery-form'),
+# publication media collections
+pug_prefix = f'{pu_prefix}/<int:publication_id>/media-collections'
+urlpatterns += path(f'{pug_prefix}/', publication_media_collection.PublicationMediaCollectionList.as_view(), name='editorial-board-publication-media-collections'),
+urlpatterns += path(f'{pug_prefix}/<int:pk>/', publication_media_collection.PublicationMediaCollectionView.as_view(), name='editorial-board-publication-media-collection'),
+urlpatterns += path(f'{pug_prefix}/<int:pk>/logs/', publication_media_collection.PublicationMediaCollectionLogsView.as_view(),
+                    name='editorial-board-publication-media-collection-logs'),
+urlpatterns += path(f'{pug_prefix}/form/', publication_media_collection.PublicationMediaCollectionFormView.as_view(),
+                    name='editorial-board-publication-media-collection-form'),
 
 # publication localizations
 pulo_prefix = f'{pu_prefix}/<int:publication_id>/localizations'
@@ -331,6 +335,8 @@ urlpatterns += path(f'{menu_prefix}/<int:pk>/', menu.MenuView.as_view(), name='e
 urlpatterns += path(f'{menu_prefix}/<int:pk>/logs/', menu.MenuLogsView.as_view(), name='editorial-board-menu-logs'),
 urlpatterns += path(f'{menu_prefix}/<int:pk>/clone/', menu.MenuCloneView.as_view(), name='editorial-board-menu-clone'),
 urlpatterns += path(f'{menu_prefix}/form/', menu.MenuFormView.as_view(), name='editorial-board-menu-form'),
+urlpatterns += path(f'{menu_prefix}/options/', menu.MenuOptionList.as_view(), name='editorial-board-menu-options'),
+urlpatterns += path(f'{menu_prefix}/options/<int:pk>/', menu.MenuOptionView.as_view(), name='editorial-board-menu-option'),
 
 # menu items
 mei_prefix = f'{menu_prefix}/<int:menu_id>/items'
@@ -356,6 +362,8 @@ urlpatterns += path(f'{eb_prefix}/locks/<int:content_type_id>/<int:object_id>/<i
 urlpatterns += path(f'{eb_prefix}/users/form/', webpath_pub_context.EditorialBoardLockUserFormView.as_view(), name='users-form'),
 urlpatterns += path(f'{eb_prefix}/redis-lock/<int:content_type_id>/<int:object_id>/',
                     locks.RedisLockView.as_view(), name='editorial-board-redis-lock'),
+urlpatterns += path(f'{eb_prefix}/redis-lock/set/',
+                    locks.RedisLockSetView.as_view(), name='editorial-board-redis-lock-set'),
 
 # users
 u_prefix = f'{eb_prefix}/users'
