@@ -1,6 +1,7 @@
 from django.contrib.auth import get_user_model
 from django.contrib.contenttypes.models import ContentType
 from django.http import Http404
+from django.shortcuts import get_object_or_404
 from django.utils.translation import gettext_lazy as _
 
 from cms.contexts.models import EditorialBoardLock, EditorialBoardLockUser
@@ -13,8 +14,8 @@ from rest_framework.response import Response
 from rest_framework.schemas.openapi import AutoSchema
 from rest_framework.views import APIView
 
-from . generics import UniCMSListCreateAPIView
-from .. concurrency import get_lock_from_cache, LOCK_MESSAGE
+from . generics import check_locks, UniCMSListCreateAPIView
+from .. concurrency import *
 from .. exceptions import LoggedPermissionDenied
 
 
@@ -64,6 +65,10 @@ class ObjectUserLocksList(UniCMSListCreateAPIView):
             if not hasattr(obj, 'is_lockable_by') or not obj.is_lockable_by(request.user):
                 raise LoggedPermissionDenied(classname=self.__class__.__name__,
                                              resource=request.method)
+
+            # redis locks
+            check_locks(obj, request.user)
+
             existent = EditorialBoardLockUser.objects.filter(lock__content_type=content_type,
                                                              lock__object_id=object_id,
                                                              user=user).first()
@@ -96,6 +101,7 @@ class ObjectUserLocksView(generics.RetrieveDestroyAPIView):
         """
         content_type_id = self.kwargs['content_type_id']
         object_id = self.kwargs['object_id']
+
         lock_id = self.kwargs['pk']
         locks = EditorialBoardLockUser.objects.filter(pk=lock_id,
                                                       lock__object_id=object_id,
@@ -105,16 +111,20 @@ class ObjectUserLocksView(generics.RetrieveDestroyAPIView):
     def delete(self, request, *args, **kwargs):
         items = self.get_queryset()
         if not items: raise Http404
-        permission = False
-        if request.user.is_superuser:
-            permission = True
-        else:
-            user_lock = items.filter(user=request.user).first()
-            if user_lock: permission = True
-        if not permission:
-            raise LoggedPermissionDenied(classname=self.__class__.__name__,
+
+        # redis locks
+        one_lock = items.first()
+        content_type_id = one_lock.lock.content_type.pk
+        object_id = one_lock.lock.object_id
+        content_type = ContentType.objects.get_for_id(content_type_id)
+        obj = content_type.get_object_for_this_type(pk=object_id)
+        check_locks(obj, request.user)
+
+        user_lock = items.filter(user=request.user).first()
+        if request.user.is_superuser or user_lock:
+            return super().delete(request, *args, **kwargs)
+        raise LoggedPermissionDenied(classname=self.__class__.__name__,
                                          resource=request.method)
-        return super().delete(request, *args, **kwargs)
 
 
 class RedisLockView(APIView):
@@ -127,9 +137,67 @@ class RedisLockView(APIView):
         content_type_id = self.kwargs['content_type_id']
         object_id = self.kwargs['object_id']
         lock = get_lock_from_cache(content_type_id, object_id)
-        if lock[0] and not lock[0] == request.user.pk:
+        if lock[0] and not lock[0] == request.user.pk: # pragma: no cover
             owner_user = get_user_model().objects.filter(pk=lock[0]).first()
             return Response({'lock': lock,
                              'message': LOCK_MESSAGE.format(user=owner_user,
                                                             ttl=lock[1])})
         return Response({})
+
+
+class RedisLockSetSchema(AutoSchema):
+    def get_operation_id(self, path, method):# pragma: no cover
+        return 'setRedisLock'
+
+    def get_operation(self, path, method): # pragma: no cover
+        op = super().get_operation(path, method)
+        op['parameters'].append(
+            {
+                "name": "content_type_id",
+                "in": "form",
+                "required": True,
+                "description": "Locking object content_type id",
+                'schema': {'type': 'integer'}
+            }
+        )
+        op['parameters'].append(
+            {
+                "name": "object_id",
+                "in": "form",
+                "required": True,
+                "description": "Locking object id",
+                'schema': {'type': 'integer'}
+            }
+        )
+        return op
+
+
+class RedisLockSetView(APIView):
+    """
+    """
+    description = ""
+    permission_classes = [IsAdminUser]
+    schema = RedisLockSetSchema()
+
+    def post(self, request, *args, **kwargs):
+        content_type_id = request.data.get('content_type_id', None)
+        object_id = request.data.get('object_id', None)
+
+        if not all([content_type_id, object_id]):
+            raise Http404
+
+        ct = get_object_or_404(ContentType, pk=content_type_id)
+        obj = get_object_or_404(ct.model_class(), pk=object_id)
+        lock = get_lock_from_cache(content_type_id, object_id)
+        if lock[0] and not lock[0] == request.user.pk: # pragma: no cover
+            owner_user = get_user_model().objects.filter(pk=lock[0]).first()
+            return Response({'lock': lock,
+                             'message': LOCK_MESSAGE.format(user=owner_user,
+                                                            ttl=lock[1])})
+        if obj.is_lockable_by(request.user):
+            set_lock_to_cache(user_id=request.user.pk,
+                              content_type_id=content_type_id,
+                              object_id=object_id)
+            return Response({'message': _('Lock successfully set')})
+        raise LoggedPermissionDenied(classname=self.__class__.__name__,
+                                     resource=request.method)
