@@ -2,6 +2,7 @@ from django.conf import settings
 from django.db import models
 from django.utils.translation import gettext_lazy as _
 
+from cms.api.utils import check_user_permission_on_object
 from cms.contexts.models_abstract import AbstractLockable
 from cms.medias.models import Media
 from cms.templates.models import (CMS_LINKS_LABELS,
@@ -13,10 +14,8 @@ from cms.templates.models import (CMS_LINKS_LABELS,
 
 class Carousel(ActivableModel, TimeStampedModel, CreatedModifiedBy,
                AbstractLockable):
-    name = models.CharField(max_length=160, blank=False,
-                            null=False, unique=False)
-    description = models.TextField(max_length=2048,
-                                   null=False, blank=False)
+    name = models.CharField(max_length=160)
+    description = models.TextField(max_length=2048)
 
     class Meta:
         ordering = ['name']
@@ -39,13 +38,15 @@ class CarouselItem(ActivableModel, TimeStampedModel,
     carousel = models.ForeignKey(Carousel,
                                  on_delete=models.CASCADE)
     image = models.ForeignKey(Media, on_delete=models.PROTECT)
-    pre_heading = models.CharField(max_length=120, blank=True, null=True,
-                                   help_text=_("Pre Heading"))
-    heading = models.CharField(max_length=120, blank=True, null=True,
-                               help_text=_("Heading"))
+    pre_heading = models.CharField(
+        max_length=120, blank=True, default='', help_text=_('Pre Heading')
+    )
+    heading = models.CharField(
+        max_length=120, blank=True, default='', help_text=_('Heading')
+    )
 
     # hopefully markdown here!
-    description = models.TextField(null=True, blank=True)
+    description = models.TextField(default='', blank=True)
 
     class Meta:
         verbose_name_plural = _("Carousel Items")
@@ -64,6 +65,11 @@ class CarouselItem(ActivableModel, TimeStampedModel,
             self.description = i18n.description
         return self
 
+    def is_lockable_by(self, user):
+        item = self.carousel
+        permission = check_user_permission_on_object(user=user, obj=item)
+        return permission['granted']
+
     def __str__(self):
         return '[{}] {}'.format(self.carousel, self.heading)
 
@@ -73,20 +79,25 @@ class CarouselItemLocalization(ActivableModel,
                                CreatedModifiedBy):
     carousel_item = models.ForeignKey(CarouselItem,
                                       on_delete=models.CASCADE)
-    language = models.CharField(choices=settings.LANGUAGES,
-                                max_length=12, null=False,blank=False,
-                                default='en')
-    pre_heading = models.CharField(max_length=120, blank=True, null=True,
-                                   help_text=_("Pre Heading"))
-    heading = models.CharField(max_length=120, blank=True, null=True,
-                               help_text=_("Heading"))
+    language = models.CharField(choices=settings.LANGUAGES, max_length=12, default='en')
+    pre_heading = models.CharField(
+        max_length=120, blank=True, default='', help_text=_('Pre Heading')
+    )
+    heading = models.CharField(
+        max_length=120, blank=True, default='', help_text=_('Heading')
+    )
 
     # hopefully markdown here!
-    description = models.TextField(blank=True, null=True)
+    description = models.TextField(blank=True, default='')
 
     class Meta:
         verbose_name_plural = _("Carousel Item Localization")
 
+    def is_lockable_by(self, user):
+        item = self.carousel_item.carousel
+        permission = check_user_permission_on_object(user=user, obj=item)
+        return permission['granted']
+
     def __str__(self):
         return '{} {}'.format(self.carousel_item, self.language)
 
@@ -98,8 +109,7 @@ class CarouselItemLink(ActivableModel, TimeStampedModel, SortableModel,
     title_preset = models.CharField(choices=CMS_LINKS_LABELS,
                                     default='custom',
                                     max_length=33)
-    title = models.CharField(max_length=120, blank=True, null=True,
-                             help_text=_("Title"))
+    title = models.CharField(max_length=120, blank=True, default='', help_text=_('Title'))
     url = models.CharField(max_length=2048)
 
     class Meta:
@@ -108,6 +118,11 @@ class CarouselItemLink(ActivableModel, TimeStampedModel, SortableModel,
     def get_title(self):
         return self.title if self.title_preset == 'custom' else self.title_preset
 
+    def is_lockable_by(self, user):
+        item = self.carousel_item.carousel
+        permission = check_user_permission_on_object(user=user, obj=item)
+        return permission['granted']
+
     def __str__(self):
         return '{} {}'.format(self.carousel_item, self.url)
 
@@ -116,15 +131,17 @@ class CarouselItemLinkLocalization(ActivableModel, TimeStampedModel,
                                    SortableModel, CreatedModifiedBy):
     carousel_item_link = models.ForeignKey(CarouselItemLink,
                                            on_delete=models.CASCADE)
-    language = models.CharField(choices=settings.LANGUAGES,
-                                max_length=12, null=False,blank=False,
-                                default='en')
-    title = models.CharField(max_length=120, blank=True, null=True,
-                             help_text=_("Title"))
+    language = models.CharField(choices=settings.LANGUAGES, max_length=12, default='en')
+    title = models.CharField(max_length=120, blank=True, default='', help_text=_('Title'))
 
     class Meta:
         verbose_name_plural = _("Carousel Item Links")
 
+    def is_lockable_by(self, user):
+        item = self.carousel_item_link.carousel_item.carousel
+        permission = check_user_permission_on_object(user=user, obj=item)
+        return permission['granted']
+
     def __str__(self):
         return '{} {}'.format(self.carousel_item_link.carousel_item.carousel,
                               self.carousel_item_link.url)
