@@ -28,10 +28,12 @@ def get_CMS_HOOKS():
 
 
 def detect_user_language(request):
-    lang = request.GET.get('lang',
-                           translation.get_language_from_request(request))
+    req_lang =  translation.get_language_from_request(request) # is browser language
+    current = request.session.get(translation.LANGUAGE_SESSION_KEY, req_lang)
+    lang = request.GET.get('lang', current)
     translation.activate(lang)
-    request.LANGUAGE_CODE = translation.get_language()
+    request.LANGUAGE_CODE = lang
+    request.session[translation.LANGUAGE_SESSION_KEY] = lang
     return lang
 
 
@@ -161,8 +163,13 @@ def log_obj_event(user, obj, data={}, action_flag=CHANGE):
     """
     msg = _("changed") if action_flag == CHANGE else _("added")
 
-    data = deepcopy(data)
-    data = dict(data)
+    # ex: FILE_UPLOAD_MAX_MEMORY_SIZE exceeded
+    # TypeError: cannot pickle '_io.BufferedRandom' object
+    try:
+        data = deepcopy(data)
+        data = dict(data)
+    except Exception:
+        data = {}
 
     # pop readonly fields from logged dict
     data.pop('id', None)
@@ -177,7 +184,7 @@ def log_obj_event(user, obj, data={}, action_flag=CHANGE):
                                 object_id = obj.pk,
                                 object_repr = obj.__str__(),
                                 action_flag = action_flag,
-                                change_message = f'{msg}: {data}' or msg)
+                                change_message = f'{msg}: {data}' if data else msg)
 
 
 def clone(obj,
