@@ -1,4 +1,7 @@
 import logging
+# import random
+import secrets
+# import string
 
 from django import template
 from django.conf import settings
@@ -46,5 +49,7 @@ def settings_value(name, **kwargs):
 
 
 @register.simple_tag
-def installed_app(app_name):
-    return app_name in settings.INSTALLED_APPS
+def random_id():
+    # letters = string.ascii_lowercase
+    # return ''.join(random.choice(letters) for i in range(10))
+    return secrets.randbelow(9999)
